@@ -1,7 +1,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 // Copyright (c) 2012-2014 Monty Program Ab
-// Copyright (c) 2015-2021 MariaDB Corporation Ab
-
+// Copyright (c) 2015-2025 MariaDB Corporation Ab
 package org.mariadb.jdbc.integration;
 
 import java.sql.SQLException;
@@ -13,7 +12,7 @@ public class GaleraTest extends Common {
 
   @Test
   public void galeraAllowedStatesTest() throws SQLException {
-    if ("galera".equals(System.getenv("srv"))) {
+    if ("galera".equals(System.getenv("DB_TYPE"))) {
       try (Connection con = createCon("galeraAllowedState=4,5,6")) {
         con.isValid(1);
       }
