@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 // Copyright (c) 2012-2014 Monty Program Ab
-// Copyright (c) 2015-2024 MariaDB Corporation Ab
+// Copyright (c) 2015-2025 MariaDB Corporation Ab
 package org.mariadb.jdbc.integration.codec;
 
 import static org.junit.jupiter.api.Assertions.*;
@@ -33,9 +33,7 @@ public class UuidCodecTest extends CommonCodecTest {
   public static void beforeAll2() throws SQLException {
     drop();
     Assumptions.assumeTrue(
-        isMariaDBServer()
-            && minVersion(10, 7, 0)
-            && hasCapability(Capabilities.EXTENDED_TYPE_INFO));
+        isMariaDBServer() && minVersion(10, 7, 0) && hasCapability(Capabilities.EXTENDED_METADATA));
     Statement stmt = sharedConn.createStatement();
     stmt.execute("CREATE TABLE UuidCodec (t1 UUID, t2 UUID, t3 UUID, t4 UUID)");
     stmt.execute("CREATE TABLE UuidCodec2 (t1 UUID)");
